@@ -421,10 +421,10 @@ class LaharFlowData(object):
                 raise ValueError('Result file {file} is not in directory {dir}'.format(file=fileIn, dir=self.dir))
         else:
             raise RuntimeError("Result must be either the name of file in directory {dirc}, or an integer".format(dirc=self.dir))
-        return
+        return fileIn
     
     def _file_type(self, filename):
-        self._valid_input_file(filename)
+        _ = self._valid_input_file(filename)
         if isinstance(filename, str):
             if filename=='MaxHeights.txt':
                 filetype = 'MaxHeights.txt'
@@ -442,7 +442,7 @@ class LaharFlowData(object):
             raise RuntimeError('variable {var} not recognized'.format(var=variable))
 
     def _get_data_column_names(self, filename):
-        self._valid_input_file(filename)
+        filename = self._valid_input_file(filename)
         if self.zipped:
             LaharFlowFilePath = _path_of_file_in_zip(filename,self._zipref)[0]
             LaharFlowFile = self._zipref.extract(LaharFlowFilePath,path=self.dir)
@@ -453,7 +453,7 @@ class LaharFlowData(object):
 
     def _get_data(self, filename):
 
-        self._valid_input_file(filename)
+        filename = self._valid_input_file(filename)
         if self.zipped:
             LaharFlowFilePath = _path_of_file_in_zip(filename, self._zipref)[0]
             LaharFlowFile = self._zipref.extract(LaharFlowFilePath, path=self.dir)
@@ -838,7 +838,7 @@ class LaharFlowData(object):
     
     def save_gtiff(self, fileIn, fileOut=None, crs=None, **kwargs):
 
-        self._valid_input_file(fileIn)
+        fileIn = self._valid_input_file(fileIn)
 
         raster = self.raster(fileIn, crs=crs)
 
@@ -864,7 +864,7 @@ class LaharFlowData(object):
                  orientation="vertical",
                  title=None):
 
-        self._valid_input_file(result)
+        _ = self._valid_input_file(result)
         filetype = self._file_type(result)
 
         self._valid_variable(variable)
